from django.db import models

import datetime



class File(models.Model):    
    created = models.DateTimeField(auto_now_add=True)
    updated = models.DateTimeField(auto_now=True)

    slug = models.SlugField( unique=True )
    file = models.FileField( upload_to='file_archive' )

    def __unicode__(self):
        return self.slug

    @models.permalink
    def get_absolute_url(self):
        return ( 'file_archive', [ self.slug ] )




from django.shortcuts import get_object_or_404, redirect

from models import File


def redirect_to_file(request, slug):
    """Find the file and redirect ot it, or 404"""

    object = get_object_or_404( File, slug=slug )
    return redirect( object.file.url )



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import datetime


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='File',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', models.DateTimeField(default=datetime.datetime.now, auto_now_add=True)),
                ('updated', models.DateTimeField(default=datetime.datetime.now, auto_now=True)),
                ('slug', models.SlugField(unique=True)),
                ('file', models.FileField(upload_to=b'file_archive')),
            ],
            options={
            },
            bases=(models.Model,),
        ),
    ]



from setuptools import setup, find_packages
setup(
    name = "django-file-archive",
    version = "0.0.2",
    packages = find_packages(),
    author = "Edmund von der Burg",
    author_email = "evdb@ecclestoad.co.uk",
    description = "Simple facility for uploading files in the Django admin",
    license = "AGPL",
    keywords = "django upload",
    install_requires = [
        'Django>=1.8',
    ]
)
